""" background tasks for pr_upload """

import os
from celery import shared_task


# helpers
def failed_upload(file, uploads):  # FIXME: syntax & opt
    """
        Determine if upload shall fail:
        file: file to check uploadability of
        uploads: uploads folder to later move the file to, if upload is granted
        The files to check follow a certain filename structure => Pressespiegel_********.pdf.
            If the 8 digit code is equivalent to one of the uploaded files codes, the upload fails.
    """
    for upload in uploads:
        if file[:22] == upload[:22]:
            return True
    return False


@shared_task
def autoremove_task(media_root):
    """
        Task to regularly upload or autoremove the added pressespiegels:
        media_root: media root path as found in one_api.settings_prod.MEDIA_ROOT
        The paths to testfile/, containing all files to upload and upload/, containing all uploaded files get read.
            Then all files to upload get checked if they are valid to be uploaded:
                1. Is the filename invalid?
                2. Does the upload fail, as determined by failed_upload()?
            If one of the above is the case, the file in question gets removed, if not it gets uploaded.
    """

    # setup
    root, uroot = media_root + 'testfile/', media_root + 'upload/'
    ls_files, ls_uploads = os.listdir(root), os.listdir(uroot)

    # check if files should be uploaded
    for file in ls_files:
        if len(file) > 26 or failed_upload(file, ls_uploads):  # FIXME: ??iwc is len even needed
            os.remove(root + file)  # autoremove invalid file
        else:
            os.rename(root + file, uroot + file)  # upload file
# TODO: add database check
